@@ -32,13 +32,13 @@ yupana <- function(dependencies = FALSE) {
   > https://inkaverse.com/articles/apps
           ")
   
-  if (dependencies == TRUE ) {
+  if (dependencies == TRUE) {
     
-    source("https://raw.githubusercontent.com/Flavjack/inti/master/inst/yupanapro/setup.r")
+    source("https://raw.githubusercontent.com/Flavjack/inti/master/inst/yupana/setup.R")
     
   }
   
-  appDir <- system.file("yupanapro", package = "inti")
+  appDir <- system.file("yupana", package = "inti")
   
   if (appDir == "") {
     
@@ -46,8 +46,6 @@ yupana <- function(dependencies = FALSE) {
          , call. = FALSE)
   }
   
-  pkgs <- system.file("yupanapro/setup.r", package = "inti")
-  
   shiny::runApp(appDir
                 , display.mode = "normal"
                 , launch.browser = TRUE
